==> qt-creator-opensource-src-4.5.1.zip: qt-creator-opensource-src-4.5.1/src/libs/clangsupport/filecontainerv2.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "filecontainerv2.h"

namespace ClangBackEnd {
namespace V2 {

QDebug operator<<(QDebug debug, const FileContainer &container)
{
    debug.nospace() << "FileContainer("
                    << container.filePath() << ", "
                    << container.commandLineArguments() << ", "
                    << container.documentRevision();

    debug.nospace() << ")";

    return debug;
}

std::ostream &operator<<(std::ostream &os, const FileContainer &container)
{
    os << "("
        << container.filePath() << ", "
        << container.commandLineArguments() << ", "
        << container.documentRevision();

    if (container.unsavedFileContent().hasContent())
        os << ", \""
            << container.unsavedFileContent();

    os << "\")";

    return os;
}

} // namespace V2
} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.9.1.zip: qt-creator-opensource-src-4.9.1/src/libs/clangsupport/filecontainerv2.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "filecontainerv2.h"

namespace ClangBackEnd {
namespace V2 {

QDebug operator<<(QDebug debug, const FileContainer &container)
{
    debug.nospace() << "FileContainer(" << container.filePath << ", "
                    << container.commandLineArguments << ", "
                    << container.unsavedFileContent.hasContent() << ", "
                    << container.documentRevision;

    debug.nospace() << ")";

    return debug;
}

} // namespace V2
} // namespace ClangBackEnd
